#!/bin/sh
# This is part of MyDbox (installer for Dropbox)
# version 1.2
# copyright (C) Giuliana Gentile a.k.a.
# Whitesnow (on Puppy Linux forum) and QuaLaPinna (mail: software@qualapinna.dyndns.org,
# blog: http://qualapinna.dyndns.org, repository: http://qualapinna.dyndns.org/repo)
# December 2014, license: GPL3 and any later versions

DROPBOX_32=https://www.dropbox.com/download?plat=lnx.x86
DROPBOX_64=https://www.dropbox.com/download?plat=lnx.x86_64

if [[ -z `ifconfig | grep -i bcast | awk '{ print $2 }' | cut -d: -f2` ]]; then
	Xdialog --title "MyDbox, no Internet available" --ok-label "I'm connected now" --cancel-label "Exit, still no net" --fill --yesno "It seems that you are not connected to Internet, required to install Dropbox. Now, you can choose if go ahead or not." 0 0
	
		if [ ! $? -eq 0 ]; then
			Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
			exit
		else
		
			if [[ -z `ifconfig | grep -i bcast | awk '{ print $2 }' | cut -d: -f2` ]]; then
				Xdialog --title "MyDbox, still no Internet" --no-buttons --fill --infobox "Still no Internet. Exit now." 4 50 2500
				Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
				exit
			fi
			
		fi

else

	if [ -d ~root/.dropbox -o -d ~spot/.dropbox ]; then
		Xdialog --title "Dropbox old configuration found" --fill --msgbox "It looks like you have already installed Dropbox before now. Unfortunately, Dropbox configuration folder can't stay, nowhere, in your personal storage file (pupsave), without lose your account settings everytime. For this reason, a new configuration folder will be created in /mnt/home and linked in your home, moving old one to /tmp (look for hidden directory \".dropbox\"). In this way, you can check, before system delete it (don't worry, it's safe to remove that folder; your synchronized files, if any already exist, will be untouched and Dropbox will fill up new configuration folder at next login)." 0 0
	
			if [ ! $? -eq 0 ]; then
				Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
				exit
			fi

		mv -b `find -L ~root ~spot -maxdepth 1 -type d -name .dropbox` /tmp 2> /dev/null
	fi

	mkdir -p /mnt/home/.dropbox
	chmod 700 /mnt/home/.dropbox

	Xdialog --title "MyDbox user choice" --ok-label "Run as root" --cancel-label "Run as spot" --fill --yesno "It's time to download and start Dropbox. First question: do you want to run it as root or spot?" 0 0

		case $? in
			0)	Xdialog --title "MyDbox arch choice" --ok-label "32 bit" --cancel-label "64 bit" --fill --yesno "Please, choose the right architecture (if you don't know what it means, select default one, 32 bit)." 0 0
			
					case $? in
						0)	wget --no-check-certificate $DROPBOX_32 -O /tmp/dropbox_x86.tar.gz 2>&1 | sed -nru '/[0-9]{1,3}%/{s/.*[^0-9]([0-9]{1,3}%).*/\1/;p}' | xargs -L 1 echo | Xdialog --title "MyDbox download" --no-close --gauge "MyDbox is downloading Dropbox..." 7 60
						
								if [ $? -eq 0 ]; then
									tar xf /tmp/dropbox_x86.tar.gz -C ~root
									rm /tmp/dropbox_x86.tar.gz
								else
									Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
									rm /tmp/dropbox_x86.tar.gz
									exit
								fi
								
							;;
						1)	wget --no-check-certificate $DROPBOX_64 -O /tmp/dropbox_x86_64.tar.gz 2>&1 | sed -nru '/[0-9]{1,3}%/{s/.*[^0-9]([0-9]{1,3}%).*/\1/;p}' | xargs -L 1 echo | Xdialog --title "MyDbox download" --no-close --gauge "MyDbox is downloading Dropbox..." 7 60
						
								if [ $? -eq 0 ]; then
									tar xf /tmp/dropbox_x86_64.tar.gz -C ~root
									rm /tmp/dropbox_x86_64.tar.gz
								else
									Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
									rm /tmp/dropbox_x86_64.tar.gz
									exit
								fi
								
							;;
						*) 	Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
							exit
							
							;;
					esac
					
				 echo -e \#\!/bin/sh "\n\nexec ~root/.dropbox-dist/dropboxd \"\$@\"" > /usr/bin/dropbox
				 ln -sf /mnt/home/.dropbox ~root
				 
				;;
			1) 	Xdialog --title "MyDbox arch choice" --ok-label "32 bit" --cancel-label "64 bit" --fill --yesno "Please, choose the right architecture (if you don't know what it means, select default one, 32 bit)." 0 0
			
					case $? in
						0)	su spot -c "wget --no-check-certificate $DROPBOX_32 -O /tmp/dropbox_x86.tar.gz 2>&1 | sed -nru '/[0-9]{1,3}%/{s/.*[^0-9]([0-9]{1,3}%).*/\1/;p}' | xargs -L 1 echo | Xdialog --title \"MyDbox download\" --no-close --gauge \"MyDbox is downloading Dropbox...\" 7 60"
						
								if [ $? -eq 0 ]; then
									tar xf /tmp/dropbox_x86.tar.gz -C ~spot
									rm /tmp/dropbox_x86.tar.gz
								else
									Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
									rm /tmp/dropbox_x86.tar.gz
									exit
								fi
								
							;;
						1)	su spot -c "wget --no-check-certificate $DROPBOX_64 -O /tmp/dropbox_x86_64.tar.gz 2>&1 | sed -nru '/[0-9]{1,3}%/{s/.*[^0-9]([0-9]{1,3}%).*/\1/;p}' | xargs -L 1 echo | Xdialog --title \"MyDbox download\" --no-close --gauge \"MyDbox is downloading Dropbox...\" 7 60"
						
								if [ $? -eq 0 ]; then
									tar xf /tmp/dropbox_x86_64.tar.gz -C ~spot
									rm /tmp/dropbox_x86_64.tar.gz
								else
									Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
									rm /tmp/dropbox_x86_64.tar.gz
									exit
								fi
								
							;;
						*) 	Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
							exit
							
							;;
					esac
					
					echo -e \#\!/bin/sh "\n\nrun-as-spot ~spot/.dropbox-dist/dropboxd \"\$@\"" > /usr/bin/dropbox
					chown -R spot.spot ~spot/.dropbox-dist
					chown -R spot.spot /mnt/home/.dropbox
					ln -sf /mnt/home/.dropbox ~spot
					
					;;
					
			*) 	Xdialog --title "MyDbox error" --fill --msgbox "Something went wrong. To run again this installer, uninstall and reinstall MyDbox package." 0 0
				exit
				
				;;
		esac
	
	chmod +x /usr/bin/dropbox
	
	Xdialog --title "Read carefully!" --no-close --fill --msgbox "This box will not disapper until you'll click \"OK\" button. Leave it on the screen, to remember things to do. In the meantime, Dropbox will start. This is the final step of this installer.\n\nImportant to know: for security reasons, especially if you run as root and do not need following service, it is a good choice to close,  on your system, 17500 listen ports (TCP/UDP), used by Dropbox for LAN synchronization. You can do it, permanently, by right clicking on your Dropbox icon in the system tray, choosing to untick \"Preferences\" > \"Bandwidth\" > \"Enable LAN sync\". Exit and start again Dropbox (there is an entry in Internet menu) to fix the change.\n\n" 0 0 &

	sleep 5
	
	exec dropbox &
	
fi